/*
 * Copyright 2005 - 2009  Zarafa B.V.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3, 
 * as published by the Free Software Foundation with the following additional 
 * term according to sec. 7:
 *  
 * According to sec. 7 of the GNU Affero General Public License, version
 * 3, the terms of the AGPL are supplemented with the following terms:
 * 
 * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
 * the Program under the AGPL does not imply a trademark license.
 * Therefore any rights, title and interest in our trademarks remain
 * entirely with us.
 * 
 * However, if you propagate an unmodified version of the Program you are
 * allowed to use the term "Zarafa" to indicate that you distribute the
 * Program. Furthermore you may use our trademarks where it is necessary
 * to indicate the intended purpose of a product or service provided you
 * use it in accordance with honest practices in industrial or commercial
 * matters.  If you want to propagate modified versions of the Program
 * under the name "Zarafa" or "Zarafa Server", you may only do so if you
 * have a written permission by Zarafa B.V. (to acquire a permission
 * please contact Zarafa at trademark@zarafa.com).
 * 
 * The interactive user interface of the software displays an attribution
 * notice containing the term "Zarafa" and/or the logo of Zarafa.
 * Interactive user interfaces of unmodified and modified versions must
 * display Appropriate Legal Notices according to sec. 5 of the GNU
 * Affero General Public License, version 3, when you propagate
 * unmodified or modified versions of the Program. In accordance with
 * sec. 7 b) of the GNU Affero General Public License, version 3, these
 * Appropriate Legal Notices must retain the logo of Zarafa or display
 * the words "Initial Development by Zarafa" if the display of the logo
 * is not reasonably feasible for technical reasons. The use of the logo
 * of Zarafa in Legal Notices is allowed for unmodified and modified
 * versions of the software.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *  
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

/**
 * --View--
 * @classDescription	View base class
 *  
 * DEPENDS ON:
 * |------> view.js
 * |----+-> *listmodule.js
 * |    |----> listmodule.js
 */

/**
 * TODO: implement default functions
 */

View.prototype.constructor = View;

/**
 * @constructor
 * @param {Int} moduleID
 * @param {HtmlElement} element
 * @param {Object} events
 * @param {XmlElement} data
 */
function View(moduleID, element, events, data)
{
}

/**
 * Function will render the view and execute this.resizeView when done
 */
View.prototype.initView = function()
{
}

View.prototype.destructor = function()
{
	// Unregister module from InputManager
	webclient.inputmanager.removeObject(webclient.getModule(this.moduleID));
}

View.prototype.execute = function()
{
}

View.prototype.showEmptyView = function()
{
}

/**
 * Function will resize all elements in the view
 */
View.prototype.resizeView = function()
{
}

/**
 * Function will show Loading text in view
 */
View.prototype.loadMessage = function()
{
	if (this.element){
		dhtml.removeEvents(this.element);
		dhtml.deleteAllChildren(this.element);
	
		this.element.innerHTML = "<center>" + _("Loading") + "...</center>";
		document.body.style.cursor = "wait";
	}
}

/**
 * Function will delete load text in view
 */
View.prototype.deleteLoadMessage = function()
{
	if (this.element){
		dhtml.deleteAllChildren(this.element);
		document.body.style.cursor = "default";
	}
}

/**
 * Get/Set cursor position, default is to ignore
 */
 
View.prototype.setCursorPosition = function(id)
{
}

View.prototype.getCursorPosition = function()
{
	return;
}

/*
 * Modify the data set in the constructor
 */
View.prototype.setData = function(data)
{
}

View.prototype.getRowNumber = function(elemid)
{
	return;
}

View.prototype.getElemIdByRowNumber = function(rownum)
{
	return;
}

View.prototype.getRowCount = function()
{
	return;
}

